/* ============================================================
   Coral Dashboard — Main Stylesheet
   ============================================================
   This file imports all CSS modules in cascade order.
   Variables must load first so all other modules can reference them.
   Animations load early since multiple modules reference keyframes.
   ============================================================ */

@import url('css/variables.css');
@import url('css/animations.css');
@import url('css/base.css');
@import url('css/layout.css');
@import url('css/components.css');
@import url('css/session.css');
@import url('css/output.css');
@import url('css/command-pane.css');
@import url('css/chat.css');
@import url('css/agentic.css');
@import url('css/history.css');
@import url('css/scheduler.css');
@import url('css/theme-configurator.css');
